@@ -16,7 +16,9 @@ glmgam.fit(c(1,1),c(0,4))
 glmgam.fit(X=cbind(1,c(1,0.5,0.5,0,0)),y=rchisq(5,df=1))
 
 ### glmnb.fit
-glmnb.fit(X=cbind(1,c(1,0.5,0.5,0,0)),y=rnbinom(5,mu=10,size=10),dispersion=0.1)
+y <- rnbinom(5,mu=10,size=10)
+glmnb.fit(X=cbind(1,c(1,0.5,0.5,0,0)),y=y,dispersion=0.1)
+glmnb.fit(X=cbind(1,c(1,0.5,0.5,0,0)),y=y,dispersion=runif(6))
 glmnb.fit(X=cbind(1,c(1,1,0,0,0)),y=c(0,0,6,2,9),dispersion=0.1)
 
 ### mixedModel2
